Class: Couchbase::Management::Options::Query::CreateIndex

Inherits:
Options::Base
  • Object
show all
Defined in:
lib/couchbase/management/query_index_manager.rb

Overview

Instance Attribute Summary collapse

Attributes inherited from Options::Base

#client_context, #parent_span, #retry_strategy, #timeout

Instance Method Summary collapse

Constructor Details

#initialize(ignore_if_exists: false, num_replicas: nil, deferred: false, condition: nil, scope_name: nil, collection_name: nil, timeout: nil, retry_strategy: nil, client_context: nil, parent_span: nil) {|self| ... } ⇒ CreateIndex

Creates an instance of options for QueryIndexManager#create_index

Parameters:

  • (defaults to: false)

    do not raise error if the index already exist

  • (defaults to: nil)

    the number of replicas that this index should have

  • (defaults to: false)

    whether the index should be created as a deferred index.

  • (defaults to: nil)

    to apply to the index

  • (defaults to: nil)

    the name of the scope

  • (defaults to: nil)

    the name of the collection

  • (defaults to: nil)

    the time in milliseconds allowed for the operation to complete

  • (defaults to: nil)

    the custom retry strategy, if set

  • (defaults to: nil)

    the client context data, if set

  • (defaults to: nil)

    if set holds the parent span, that should be used for this request

Yield Parameters:



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/couchbase/management/query_index_manager.rb', line 87

def initialize(ignore_if_exists: false,
               num_replicas: nil,
               deferred: false,
               condition: nil,
               scope_name: nil,
               collection_name: nil,
               timeout: nil,
               retry_strategy: nil,
               client_context: nil,
               parent_span: nil)
  super(timeout: timeout, retry_strategy: retry_strategy, client_context: client_context, parent_span: parent_span)
  @ignore_if_exists = ignore_if_exists
  @num_replicas = num_replicas
  @deferred = deferred
  @condition = condition
  @scope_name = scope_name
  @collection_name = collection_name
  yield self if block_given?
end

Instance Attribute Details

#collection_nameString?

Returns:



70
71
72
# File 'lib/couchbase/management/query_index_manager.rb', line 70

def collection_name
  @collection_name
end

#conditionString?

Returns:



68
69
70
# File 'lib/couchbase/management/query_index_manager.rb', line 68

def condition
  @condition
end

#deferredBoolean

Returns:



67
68
69
# File 'lib/couchbase/management/query_index_manager.rb', line 67

def deferred
  @deferred
end

#ignore_if_existsBoolean

Returns:



65
66
67
# File 'lib/couchbase/management/query_index_manager.rb', line 65

def ignore_if_exists
  @ignore_if_exists
end

#num_replicasInteger?

Returns:



66
67
68
# File 'lib/couchbase/management/query_index_manager.rb', line 66

def num_replicas
  @num_replicas
end

#scope_nameString?

Returns:



69
70
71
# File 'lib/couchbase/management/query_index_manager.rb', line 69

def scope_name
  @scope_name
end

Instance Method Details

#to_backendObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

API:

  • private



108
109
110
111
112
113
114
115
116
117
118
# File 'lib/couchbase/management/query_index_manager.rb', line 108

def to_backend
  {
    timeout: Utils::Time.extract_duration(@timeout),
    ignore_if_exists: @ignore_if_exists,
    condition: @condition,
    deferred: @deferred,
    num_replicas: @num_replicas,
    scope_name: @scope_name,
    collection_name: @collection_name,
  }
end