Class: Couchbase::Management::Options::View::DropDesignDocument

Inherits:
Options::Base
  • Object
show all
Defined in:
lib/couchbase/management/view_index_manager.rb

Overview

Constant Summary collapse

DEFAULT =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

new.freeze

Instance Attribute Summary

Attributes inherited from Options::Base

#client_context, #parent_span, #retry_strategy, #timeout

Instance Method Summary collapse

Methods inherited from Options::Base

#to_backend

Constructor Details

#initialize(timeout: nil, retry_strategy: nil, parent_span: nil) {|| ... } ⇒ DropDesignDocument

Creates an instance of options for ViewIndexManager#drop_design_document

Parameters:

  • timeout (Integer, #in_milliseconds, nil) (defaults to: nil)

    the time in milliseconds allowed for the operation to complete

  • retry_strategy (Proc, nil) (defaults to: nil)

    the custom retry strategy, if set

  • parent_span (Span, nil) (defaults to: nil)

    if set holds the parent span, that should be used for this request

Yield Parameters:



93
94
95
96
97
98
# File 'lib/couchbase/management/view_index_manager.rb', line 93

def initialize(timeout: nil,
               retry_strategy: nil,
               parent_span: nil)
  super
  yield self if block_given?
end