Method: Couchbase::Management::QueryIndex#condition
- Defined in:
- lib/couchbase/management/query_index_manager.rb
#condition ⇒ String
Note:
that the query service can present the condition in a slightly different manner from when you declared the index. For instance it will wrap expressions with parentheses and show the fields in an escaped format (surrounded by backticks).
Returns the string representation of the index’s condition (the WHERE clause of the index), or an empty Optional if no condition was set.
660 661 662 |
# File 'lib/couchbase/management/query_index_manager.rb', line 660 def condition @condition end |