Method: Couchbase::MutateInSpec.array_append
- Defined in:
- lib/couchbase/subdoc.rb
.array_append(path, values) ⇒ MutateInSpec
Creates a command with the intention of appending a value to an existing JSON array.
Will error if the last element of the path does not exist or is not an array.
163 164 165 |
# File 'lib/couchbase/subdoc.rb', line 163 def self.array_append(path, values) new(:array_push_last, path, values) end |