Class: Couchbase::Management::SearchIndex
- Inherits:
-
Object
- Object
- Couchbase::Management::SearchIndex
- Defined in:
- lib/couchbase/management/search_index_manager.rb
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the index.
-
#params ⇒ Hash
Index properties such as store type and mappings.
-
#plan_params ⇒ Hash
Plan properties such a number of replicas and number of partitions.
-
#source_name ⇒ String
Name of the source of the data for the index (e.g. bucket name).
-
#source_params ⇒ Hash
Extra parameters for the source.
-
#source_type ⇒ String
Type of the data source.
-
#source_uuid ⇒ String
The UUID of the ata source, this can be used to more tightly tie the index to a source.
-
#type ⇒ String
Type of the index.
-
#uuid ⇒ String
UUID is required for update.
Instance Method Summary collapse
-
#initialize {|self| ... } ⇒ SearchIndex
constructor
A new instance of SearchIndex.
- #to_backend ⇒ Object private
Constructor Details
#initialize {|self| ... } ⇒ SearchIndex
Returns a new instance of SearchIndex.
627 628 629 630 631 |
# File 'lib/couchbase/management/search_index_manager.rb', line 627 def initialize @type = "fulltext-index" @source_type = "couchbase" yield self if block_given? end |
Instance Attribute Details
#name ⇒ String
Returns name of the index.
600 601 602 |
# File 'lib/couchbase/management/search_index_manager.rb', line 600 def name @name end |
#params ⇒ Hash
Returns index properties such as store type and mappings.
609 610 611 |
# File 'lib/couchbase/management/search_index_manager.rb', line 609 def params @params end |
#plan_params ⇒ Hash
Returns plan properties such a number of replicas and number of partitions.
624 625 626 |
# File 'lib/couchbase/management/search_index_manager.rb', line 624 def plan_params @plan_params end |
#source_name ⇒ String
Returns name of the source of the data for the index (e.g. bucket name).
612 613 614 |
# File 'lib/couchbase/management/search_index_manager.rb', line 612 def source_name @source_name end |
#source_params ⇒ Hash
Returns extra parameters for the source. These are usually things like advanced connection and tuning.
621 622 623 |
# File 'lib/couchbase/management/search_index_manager.rb', line 621 def source_params @source_params end |
#source_type ⇒ String
Returns type of the data source.
615 616 617 |
# File 'lib/couchbase/management/search_index_manager.rb', line 615 def source_type @source_type end |
#source_uuid ⇒ String
Returns the UUID of the ata source, this can be used to more tightly tie the index to a source.
618 619 620 |
# File 'lib/couchbase/management/search_index_manager.rb', line 618 def source_uuid @source_uuid end |
#type ⇒ String
Returns type of the index.
603 604 605 |
# File 'lib/couchbase/management/search_index_manager.rb', line 603 def type @type end |
#uuid ⇒ String
Returns UUID is required for update. It provides means of ensuring consistency.
606 607 608 |
# File 'lib/couchbase/management/search_index_manager.rb', line 606 def uuid @uuid end |
Instance Method Details
#to_backend ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
634 635 636 637 638 639 640 641 642 643 644 645 646 |
# File 'lib/couchbase/management/search_index_manager.rb', line 634 def to_backend { name: name, type: type, uuid: uuid, params: (JSON.generate(params) if params), source_name: source_name, source_type: source_type, source_uuid: source_uuid, source_params: (JSON.generate(source_params) if source_params), plan_params: (JSON.generate(plan_params) if plan_params), } end |